Stan Math Library: stan/math/prim/scal/fun/exp2.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

exp2.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_SCAL_FUN_EXP2_HPP
2 #define STAN_MATH_PRIM_SCAL_FUN_EXP2_HPP
3
4 #include <boost/math/tools/promotion.hpp>
5 #include <cmath>
6
7 namespace stan {
8 namespace math {
9
21 template <typename T>
22 inline typename boost::math::tools::promote_args<T>::type
23 exp2(const T y) {
24 using std::pow;
25 return pow(2.0, y);
26 }
27
28 }
29 }
30 #endif
stan
Definition: log_sum_exp.hpp:8
stan::math::exp2
fvar< T > exp2(const fvar< T > &x)
Definition: exp2.hpp:14
stan::math::pow
fvar< T > pow(const fvar< T > &x1, const fvar< T > &x2)
Definition: pow.hpp:18

[ Stan Home Page ] © 2011–2016, Stan Development Team.